import React, { useState, useEffect } from 'react';
import { Link, useNavigate, useLocation } from 'react-router-dom';
import { Menu, X, ChevronDown } from 'lucide-react';

interface NavbarProps {
  logo?: string;
}

const Navbar = () => {
  const [isOpen, setIsOpen] = useState(false);
  const [isScrolled, setIsScrolled] = useState(false);
  const [isServicesOpen, setIsServicesOpen] = useState(false);
  const [logoError, setLogoError] = useState(false);
  const navigate = useNavigate();
  const location = useLocation();

  const services = [
    { name: 'AI Phone Assistant', href: '#ai-phone-assistant' },
    { name: 'Automated Pipelines', href: '#automation-workflows' },
    { name: 'Omnichannel AI', href: '#omnichannel' },
    { name: 'Reputation Management', href: '#reputation' }
  ];

  const handleNavigation = (path: string) => {
    if (path.startsWith('#')) {
      if (location.pathname !== '/') {
        navigate('/' + path);
      } else {
        const element = document.querySelector(path);
        if (element) {
          window.scrollTo({ top: element.offsetTop - 80, behavior: 'smooth' });
        } else {
          window.scrollTo({ top: 0, behavior: 'smooth' });
        }
      }
    } else {
      navigate(path);
      window.scrollTo({ top: 0, behavior: 'smooth' });
    }
    // Close mobile menu after navigation
    setIsOpen(false);
  };

  useEffect(() => {
    const handleScroll = () => {
      setIsScrolled(window.scrollY > 0);
    };

    window.addEventListener('scroll', handleScroll);
    return () => window.removeEventListener('scroll', handleScroll);
  }, []);

  return (
    <nav className={`fixed w-full z-50 transition-all duration-300 ${
      isScrolled ? 'bg-white/80 backdrop-blur-xl shadow-sm py-4' : 'bg-transparent py-6'
    }`}>
      <div className="container">
        <div className="flex items-center justify-between">
          <div className="flex-shrink-0 h-12">
            <button 
              onClick={() => handleNavigation('#hero')} 
              className="flex items-center h-full"
            >
              {!logoError ? (
                <img
                  src="/logo.png"
                  alt="Sales Assist AI"
                  className="h-full w-auto"
                  onError={() => setLogoError(true)}
                />
              ) : (
                <span className="text-2xl font-bold text-gradient">
                  SALES ASSIST AI
                </span>
              )}
            </button>
          </div>
          
          <div className="hidden md:block">
            <div className="ml-10 flex items-baseline space-x-8">
              <button onClick={() => handleNavigation('#hero')} className="nav-link">Home</button>
              <button onClick={() => handleNavigation('#why-choose-us')} className="nav-link">Why Us</button>
              
              {/* Services Dropdown */}
              <div className="relative group">
                <button 
                  className="nav-link inline-flex items-center gap-1"
                  onMouseEnter={() => setIsServicesOpen(true)}
                  onMouseLeave={() => setIsServicesOpen(false)}
                >
                  Services
                  <ChevronDown className="w-4 h-4" />
                </button>
                
                {/* Dropdown Menu */}
                <div 
                  className={`absolute left-0 mt-2 w-64 rounded-xl bg-white shadow-soft border border-primary-100/50 transition-all duration-200 ${
                    isServicesOpen ? 'opacity-100 visible translate-y-0' : 'opacity-0 invisible -translate-y-2'
                  }`}
                  onMouseEnter={() => setIsServicesOpen(true)}
                  onMouseLeave={() => setIsServicesOpen(false)}
                >
                  <div className="p-2">
                    {services.map((service, index) => (
                      <a
                        key={index}
                        className="block px-4 py-2 text-sm text-secondary-600 hover:text-primary-600 hover:bg-primary-50 rounded-lg transition-colors"
                        onClick={(e) => {
                          e.preventDefault();
                          handleNavigation(service.href);
                          setIsServicesOpen(false);
                        }}
                        href="#"
                      >
                        {service.name}
                      </a>
                    ))}
                  </div>
                </div>
              </div>
              
              <Link to="/process" className="nav-link">Our Process</Link>
              <button onClick={() => handleNavigation('#about')} className="nav-link">About</button>
              <Link to="/demo" className="nav-link">Online Demos</Link>
              <button onClick={() => handleNavigation('#contact')} className="btn-primary">
                Contact
              </button>
            </div>
          </div>

          <div className="md:hidden">
            <button 
              onClick={() => setIsOpen(!isOpen)} 
              className="text-secondary-900 hover:text-primary-500 transition-colors"
            >
              {isOpen ? <X size={24} /> : <Menu size={24} />}
            </button>
          </div>
        </div>
      </div>

      {/* Mobile Menu */}
      {isOpen && (
        <div className="md:hidden absolute w-full bg-white/95 backdrop-blur-xl shadow-lg">
          <div className="px-2 pt-2 pb-3 space-y-1">
            <button onClick={() => handleNavigation('#hero')} className="block w-full text-left px-3 py-2 nav-link">
              Home
            </button>
            <button onClick={() => handleNavigation('#why-choose-us')} className="block w-full text-left px-3 py-2 nav-link">
              Why Us
            </button>
            
            {/* Mobile Services Links */}
            <div className="px-3 py-2">
              <div className="font-medium text-secondary-900 mb-2">Services</div>
              <div className="space-y-1 pl-4">
                {services.map((service, index) => (
                  <button
                    key={index}
                    className="block py-1 text-sm text-secondary-600 hover:text-primary-600 transition-colors"
                    onClick={(e) => {
                      e.preventDefault();
                      handleNavigation(service.href);
                    }}
                  >
                    {service.name}
                  </button>
                ))}
              </div>
            </div>
            
            <Link 
              to="/process" 
              className="block px-3 py-2 nav-link"
              onClick={() => setIsOpen(false)}
            >
              Our Process
            </Link>
            <button onClick={() => handleNavigation('#about')} className="block w-full text-left px-3 py-2 nav-link">
              About
            </button>
            <Link 
              to="/demo" 
              className="block px-3 py-2 nav-link"
              onClick={() => setIsOpen(false)}
            >
              Online Demos
            </Link>
            <button onClick={() => handleNavigation('#contact')} className="block w-full text-left px-3 py-2 nav-link">
              Contact
            </button>
          </div>
        </div>
      )}
    </nav>
  );
};

export default Navbar;